@@ -73,3 +73,25 @@ is_named <- function(x) {
 names_are_invalid <- function(x) {
   x == "" | is.na(x)
 }
+
+#' Build a `data.frame` from a variety of inputs including atomic vectors, lists and other `data.frame`s
+#' @noRd
+build_data_frame <- function(x, nms = NULL) {
+  res <- if (is.atomic(x)) {
+    data.frame(x)
+  } else if (is.list(x) && !is.data.frame(x)) {
+    data.frame(I(x))
+  } else if (is.data.frame(x)) {
+    x
+  }
+  if (!is.null(nms)) colnames(res) <- nms
+  res
+}
+
+#' Check whether any elements of a list are nested
+#' @param lst A `list()`
+#' @examples
+#' is_nested(list(a = 1, b = 2, c = 3))
+#' is_nested(list(a = 1, b = list(c = 2, d = 3)))
+#' @noRd
+is_nested <- function(lst) vapply(lst, function(x) inherits(x[1L], "list"), FALSE)
